summaryrefslogtreecommitdiffstats
path: root/kompare/libdialogpages/pagebase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kompare/libdialogpages/pagebase.cpp')
-rw-r--r--kompare/libdialogpages/pagebase.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kompare/libdialogpages/pagebase.cpp b/kompare/libdialogpages/pagebase.cpp
index 33c45dba..a2061a2b 100644
--- a/kompare/libdialogpages/pagebase.cpp
+++ b/kompare/libdialogpages/pagebase.cpp
@@ -36,7 +36,7 @@ PageBase::~PageBase()
TQSize PageBase::sizeHintForWidget( TQWidget* widget )
{
//
// The size is computed by adding the tqsizeHint().height() of all
// widget tqchildren and taking the width of the widest child and adding
// tqlayout()->margin() and tqlayout()->spacing()
//
@@ -57,7 +57,7 @@ TQSize PageBase::sizeHintForWidget( TQWidget* widget )
numChild += 1;
TQWidget *w=((TQWidget*)o);
- TQSize s = w->tqsizeHint();
+ TQSize s = w->sizeHint();
if( s.isEmpty() == true )
{
s = TQSize( 50, 100 ); // Default size
@@ -36,7 +36,7 @@ PageBase::~PageBase()
{
//
- // The size is computed by adding the tqsizeHint().height() of all
+ // The size is computed by adding the sizeHint().height() of all
// widget tqchildren and taking the width of the widest child and adding
// tqlayout()->margin() and tqlayout()->spacing()